@@ -64,7 +64,7 @@ def prepare_table(xjson,xheader=None) :
         return (data[1:],data[0])
 
 class xtable:
-    def __init__(self, data=None, header=None, cols=None, noheader=False,tree=False,maxrows=2**30, widthhint=None,rowperpage=2**30):
+    def __init__(self, data=None, header=None, cols=None, noheader=False,tree=False,maxrows=2**30, widthhint=None,rowperpage=2**30,debug=False):
         self.__noheader = noheader
         self.__maxrows = maxrows
         self.__rowperpage = rowperpage or 2**30
@@ -85,6 +85,7 @@ class xtable:
                 self.__header = self.__data[0]
                 self.__data = self.__data[1:self.__maxrows]
         self.__num_of_cols = len(self.__header)
+        self.__debug = debug
 
     def get_data(self) :
         return self.__data
@@ -262,6 +263,9 @@ class xtable:
         return zip_longest(*[self.__splitstring(str(c), width[ix]) for ix,c in enumerate(row)], fillvalue="")
 
     def __repr__(self):
+        if self.__debug :
+            print("# self.__header = ",self.__header, file=sys.stderr, flush=True)
+            print("# self.__data = \n",self.__data, file=sys.stderr, flush=True)
         def supports_color():
             plat = sys.platform
             supported_platform = plat != 'Pocket PC' and (plat != 'win32' or 'ANSICON' in os.environ)
@@ -317,10 +321,10 @@ class xtable:
                     hc = int(m.group(1))
                 else :
                     hc = 21
-                res += '\033[1m' + color(fmtstr.format(*xhdr).rstrip(),fg=hc) + '\033[0m' + "\n"
+                res += '\033[1m' + color(fmtstr.format(*xhdr).strip(),fg=hc) + '\033[0m' + "\n"
                 res += "|".join(['-'*(int(w)) for w in width]) + "\n"
             else :
-                res += fmtstr.format(*xhdr).rstrip() + "\n"
+                res += fmtstr.format(*xhdr).strip() + "\n"
                 res += "|".join(['-'*(int(w)) for w in width]) + "\n"
             headlines = res
         oldrow = None
@@ -370,7 +374,7 @@ def tokenize(s):
     while True:
         m = re.search(r"\S+\s*", s[offset:])
         if m:
-            tokens.append([offset + m.start(), offset + m.end(), m.group().rstrip()])
+            tokens.append([offset + m.start(), offset + m.end(), m.group().strip()])
             offset += m.end()
         else:
             break
@@ -447,7 +451,7 @@ def xtable_main():
             header.extend(re.split(r"{}".format(args.sepchar), mhdr))
         else:
             xheader = tokenize(mhdr)
-            header = [v.rstrip() for (s, t, v) in xheader]
+            header = [v.strip() for (s, t, v) in xheader]
     data = list()
     lno = 0
     INPUT = sys.stdin
@@ -513,18 +517,18 @@ def xtable_main():
             for c, nc in colsdict.items():
                 ln = re.sub(c, nc, ln)
         if not args.table:
-            arr = re.split(r"{}".format(args.sepchar), ln.rstrip())
+            arr = re.split(r"{}".format(args.sepchar), ln.strip())
         else:
             if xheader:
-                arr = [ln[s:t].rstrip() for (s, t, v) in xheader]
+                arr = [ln[s:t].strip() for (s, t, v) in xheader]
             else:
                 for c, nc in colsdict.items():
                     ln = re.sub(c, nc, ln)
                 xheader = tokenize(ln)
                 if _args_lineno:
-                    header = ["#"] + [v.rstrip() for (s, t, v) in xheader]
+                    header = ["#"] + [v.strip() for (s, t, v) in xheader]
                 else:
-                    header = [v.rstrip() for (s, t, v) in xheader]
+                    header = [v.strip() for (s, t, v) in xheader]
                 continue
         if len(header) == 0 or (_args_lineno and len(header) == 1):
             if not args.table:
@@ -561,6 +565,7 @@ def xtable_main():
                 tree=args.tree,
                 widthhint=args.widthhint,
                 rowperpage=args.page,
+                debug=args.debug
             )
     if args.debug :
         dump_xtable(xt)
